#include <stdio.h>
#include "a_station.h"
#include <stdlib.h>
#include <string.h>

struct station* create_station(){
   struct station* station = (struct station*)calloc(1,sizeof(struct station));
   station->tracks = (struct car**)calloc(STATION_SIZE, sizeof(struct car*));
   station->track_count = STATION_SIZE;
   return station;
}

void destroy_station(struct station* station){
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            struct car* temp = current;
            current = current->next;
            free(temp);
        }
    }
    free(station->tracks);
    free(station);
}

int select_track(struct station* station, const char* target){
    size_t length = strlen(target);
    int sum = 0;
    for (size_t i = 0; i < length; i++) {
        sum += target[i];
    }
    return sum % station->track_count;
}

void add_target_capacity(struct station* station,const char* target, int capacity){
    int track = select_track(station, target);
    struct car* current = station->tracks[track];

    while (current) {
        if (strcmp(current->value, target) == 0) {
            current->capacity += capacity;
            return;
        }
        current = current->next;
    }

    struct car* new_car = malloc(sizeof(struct car));
    strncpy(new_car->value, target, TARGET_SIZE - 1);
    new_car->value[TARGET_SIZE - 1] = '\0';
    new_car->capacity = capacity;
    new_car->next = station->tracks[track];
    station->tracks[track] = new_car;
}

int get_target_capacity(struct station* station, const char* target) {
    int track = select_track(station, target);
    struct car* current = station->tracks[track];

    while (current) {
        if (strcmp(current->value, target) == 0) {
            return current->capacity;
        }
        current = current->next;
    }

    return 0;
}

int count_targets(struct station* station) {
    int count = 0;
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            count++;
            current = current->next;
        }
    }
    return count;
}

int count_capacity(struct station* station) {
    int total_capacity = 0;
    for (int i = 0; i < station->track_count; i++) {
        struct car* current = station->tracks[i];
        while (current) {
            total_capacity += current->capacity;
            current = current->next;
        }
    }
    return total_capacity;
}


